"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OAuthURLState = void 0;
class OAuthURLState {
    constructor(provider, redirectTabId = undefined) {
        this.provider = provider;
        this.redirectTabId = redirectTabId;
    }
    getEncodedState() {
        return encodeURIComponent(JSON.stringify({
            provider: this.provider,
            redirectTabId: this.redirectTabId,
        }));
    }
    overrideUrlWithState(url) {
        const urlObj = new URL(url);
        const state = urlObj.searchParams.get("state");
        if (state) {
            const stateObj = JSON.parse(decodeURIComponent(state));
            const overridedStateObj = {
                ...stateObj,
                provider: this.provider,
                redirectTabId: this.redirectTabId,
            };
            urlObj.searchParams.set("state", encodeURIComponent(JSON.stringify(overridedStateObj)));
            urlObj.searchParams.set("state", this.getEncodedState());
        }
        else {
            urlObj.searchParams.set("state", this.getEncodedState());
        }
        return urlObj.toString();
    }
    static getParsedState(state) {
        const { provider, redirectTabId } = JSON.parse(decodeURIComponent(state));
        return new OAuthURLState(provider, redirectTabId);
    }
}
exports.OAuthURLState = OAuthURLState;
//# sourceMappingURL=OAuthURLState.js.map