"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueryStatusMigrator = exports.QueryStatus = void 0;
const VersionedObject_js_1 = require("../../businessObjects/versioned/VersionedObject.js");
/**
 * This object stores the state of processing for a recieved SDQL Query. Once we hear about a query
 * from the blockchain, we should create a QueryStatus object for that query that we can use to
 * track the progress. The query is recieved but not immediately processed for insights. It is
 * immediately processed for EligibleAds. Once all EligibleAds have been viewed (via core.getAd()),
 * OR the user has indicated they don't want to see any more ads for the query (via core.completeShowingAds()),
 * the query should be processed and insights generated. The Insights and any Ad Signatures collected
 * are returned to the IP.
 * @param queryCID
 * @param status Current status of the query
 * @param expirationDate Technically retrievable from IPFS, we'll cache it here. We need to process the query before this date, so periodically we need to look for queries that are about to expire.
 */
class QueryStatus extends VersionedObject_js_1.VersionedObject {
    constructor(consentContractAddress, queryCID, receivedBlock, status, expirationDate, rewardsParameters) {
        super();
        this.consentContractAddress = consentContractAddress;
        this.queryCID = queryCID;
        this.receivedBlock = receivedBlock;
        this.status = status;
        this.expirationDate = expirationDate;
        this.rewardsParameters = rewardsParameters;
    }
    getVersion() {
        return QueryStatus.CURRENT_VERSION;
    }
}
exports.QueryStatus = QueryStatus;
QueryStatus.CURRENT_VERSION = 2;
class QueryStatusMigrator extends VersionedObject_js_1.VersionedObjectMigrator {
    getCurrentVersion() {
        return QueryStatus.CURRENT_VERSION;
    }
    factory(data) {
        return new QueryStatus(data["consentContractAddress"], data["queryCID"], data["receivedBlock"], data["status"], data["expirationDate"], data["rewardsParameters"]);
    }
    getUpgradeFunctions() {
        return new Map([
            [
                1,
                (data, version) => {
                    // The only rewards parameter we care about is the recieving address. That will be added
                    // on by deliverInsights() if it's missing
                    data["rewardsParameters"] = null;
                    return data;
                },
            ],
        ]);
    }
}
exports.QueryStatusMigrator = QueryStatusMigrator;
//# sourceMappingURL=QueryStatus.js.map