import { VersionedObject, VersionedObjectMigrator } from "../../businessObjects/versioned/VersionedObject.js";
import { ESocialType } from "../../enum/index.js";
import { DiscordID, Integer, ISO8601DateString, SocialPrimaryKey, UnixTimestamp, URLString, Username } from "../../primitives/index.js";
export declare abstract class SocialGroupProfile extends VersionedObject {
    pKey: SocialPrimaryKey;
    type: ESocialType;
    ownerId?: SocialPrimaryKey | undefined;
    static CURRENT_VERSION: number;
    constructor(pKey: SocialPrimaryKey, type: ESocialType, ownerId?: SocialPrimaryKey | undefined);
}
export declare class InvalidSocialGroupProfile extends SocialGroupProfile {
    pKey: SocialPrimaryKey;
    type: ESocialType;
    ownerId: SocialPrimaryKey;
    static CURRENT_VERSION: number;
    constructor(pKey: SocialPrimaryKey, type: ESocialType, ownerId: SocialPrimaryKey);
    getVersion(): number;
}
export declare class SocialGroupProfileMigrator extends VersionedObjectMigrator<SocialGroupProfile> {
    getCurrentVersion(): number;
    protected discordMigrator: DiscordGuildProfileMigrator;
    constructor();
    protected factory(data: Record<string, unknown>): SocialGroupProfile;
    protected getUpgradeFunctions(): Map<number, (data: Record<string, unknown>, version: number) => Record<string, unknown>>;
}
export declare class DiscordGuildProfile extends SocialGroupProfile {
    id: DiscordID;
    discordUserProfileId: DiscordID | undefined;
    name: string;
    isOwner: boolean;
    permissions: Integer;
    icon: URLString | null;
    joinedAt: UnixTimestamp | null;
    static CURRENT_VERSION: number;
    constructor(id: DiscordID, discordUserProfileId: DiscordID | undefined, // this should be translated to ownerId
    name: string, isOwner: boolean, permissions: Integer, icon: URLString | null, joinedAt: UnixTimestamp | null);
    deriveKey(id: DiscordID): SocialPrimaryKey;
    getVersion(): number;
}
export interface DiscordGuildProfileAPIResponse {
    id: DiscordID;
    name: string;
    icon: URLString;
    owner: boolean;
    permissions: Integer;
}
export interface DiscordGuildMembershipAPIResponse {
    is_pending: boolean;
    joined_at: ISO8601DateString;
    user: {
        id: DiscordID;
        username: Username;
    };
}
export declare class DiscordGuildProfileMigrator {
    factory(data: Record<string, unknown>): DiscordGuildProfile;
}
//# sourceMappingURL=SocialGroupProfile.d.ts.map