"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DiscordGuildProfileMigrator = exports.DiscordGuildProfile = exports.SocialGroupProfileMigrator = exports.InvalidSocialGroupProfile = exports.SocialGroupProfile = void 0;
const VersionedObject_js_1 = require("../../businessObjects/versioned/VersionedObject.js");
const index_js_1 = require("../../enum/index.js");
const index_js_2 = require("../../primitives/index.js");
class SocialGroupProfile extends VersionedObject_js_1.VersionedObject {
    constructor(pKey, type, ownerId) {
        super();
        this.pKey = pKey;
        this.type = type;
        this.ownerId = ownerId;
    }
}
exports.SocialGroupProfile = SocialGroupProfile;
SocialGroupProfile.CURRENT_VERSION = 1;
class InvalidSocialGroupProfile extends SocialGroupProfile {
    constructor(pKey, type, ownerId) {
        super(pKey, type, ownerId);
        this.pKey = pKey;
        this.type = type;
        this.ownerId = ownerId;
    }
    getVersion() {
        return InvalidSocialGroupProfile.CURRENT_VERSION;
    }
}
exports.InvalidSocialGroupProfile = InvalidSocialGroupProfile;
InvalidSocialGroupProfile.CURRENT_VERSION = 1;
class SocialGroupProfileMigrator extends VersionedObject_js_1.VersionedObjectMigrator {
    getCurrentVersion() {
        return SocialGroupProfile.CURRENT_VERSION;
    }
    constructor() {
        super();
        this.discordMigrator = new DiscordGuildProfileMigrator();
    }
    factory(data) {
        switch (data["type"]) {
            case index_js_1.ESocialType.DISCORD:
                return this.discordMigrator.factory(data);
        }
        return new InvalidSocialGroupProfile(// Cannot return null
        (0, index_js_2.SocialPrimaryKey)(data["pKey"]), index_js_1.ESocialType[data["type"]], (0, index_js_2.SocialPrimaryKey)(data["ownerId"]));
    }
    getUpgradeFunctions() {
        return new Map();
    }
}
exports.SocialGroupProfileMigrator = SocialGroupProfileMigrator;
class DiscordGuildProfile extends SocialGroupProfile {
    constructor(id, discordUserProfileId, // this should be translated to ownerId
    name, isOwner, permissions, icon, joinedAt) {
        super((0, index_js_2.SocialPrimaryKey)(`discord-group-${id}`), index_js_1.ESocialType.DISCORD, discordUserProfileId
            ? (0, index_js_2.SocialPrimaryKey)(`discord-${discordUserProfileId}`)
            : undefined);
        this.id = id;
        this.discordUserProfileId = discordUserProfileId;
        this.name = name;
        this.isOwner = isOwner;
        this.permissions = permissions;
        this.icon = icon;
        this.joinedAt = joinedAt;
    }
    deriveKey(id) {
        return (0, index_js_2.SocialPrimaryKey)(`discord-group-${id}`);
    }
    getVersion() {
        return DiscordGuildProfile.CURRENT_VERSION;
    }
}
exports.DiscordGuildProfile = DiscordGuildProfile;
DiscordGuildProfile.CURRENT_VERSION = 1;
class DiscordGuildProfileMigrator {
    factory(data) {
        return new DiscordGuildProfile((0, index_js_2.DiscordID)(data["id"]), (0, index_js_2.DiscordID)(data["discordUserProfileId"]), (0, index_js_2.Username)(data["name"]), data["isOwner"], (0, index_js_2.Integer)(data["permissions"]), data["icon"], (0, index_js_2.UnixTimestamp)(data["joinedAt"]));
    }
}
exports.DiscordGuildProfileMigrator = DiscordGuildProfileMigrator;
//# sourceMappingURL=SocialGroupProfile.js.map