"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.compareComponentStatus = exports.EComponentStatus = void 0;
var EComponentStatus;
(function (EComponentStatus) {
    EComponentStatus["InUse"] = "In Use";
    EComponentStatus["Available"] = "Available";
    EComponentStatus["TemporarilyDisabled"] = "Temporarily Disabled";
    EComponentStatus["Disabled"] = "Disabled";
    EComponentStatus["Error"] = "Error";
    EComponentStatus["NoKeyProvided"] = "NoKeyProvided";
})(EComponentStatus || (exports.EComponentStatus = EComponentStatus = {}));
/**
 * Returns the "better" of the two EComponentStatus enums.
 * InUse > Available > TemporarilyDisabled > Disabled > Error > NoKeyProvided
 * @param lhs
 * @param rhs
 * @returns The better of the two statuses
 */
function compareComponentStatus(lhs, rhs) {
    if (lhs == EComponentStatus.InUse) {
        return lhs;
    }
    else if (lhs == EComponentStatus.Available &&
        [
            EComponentStatus.TemporarilyDisabled,
            EComponentStatus.Disabled,
            EComponentStatus.Error,
            EComponentStatus.NoKeyProvided,
        ].includes(rhs)) {
        return lhs;
    }
    else if (lhs == EComponentStatus.TemporarilyDisabled &&
        [
            EComponentStatus.Disabled,
            EComponentStatus.Error,
            EComponentStatus.NoKeyProvided,
        ].includes(rhs)) {
        return lhs;
    }
    else if (lhs == EComponentStatus.Disabled &&
        [EComponentStatus.Error, EComponentStatus.NoKeyProvided].includes(rhs)) {
        return rhs;
    }
    else if (lhs == EComponentStatus.Error &&
        [EComponentStatus.NoKeyProvided].includes(rhs)) {
        return lhs;
    }
    return rhs;
}
exports.compareComponentStatus = compareComponentStatus;
//# sourceMappingURL=EComponentStatus.js.map