"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EQueryEvents = void 0;
/**
 * Important Note on Evaluation Events:
 *
 * The evaluation events also encompass data access events. For instance, if an age evaluation
 * takes 10ms and the corresponding age data access event takes 9ms, then the other processes
 * in the age query approximately consume 1ms.
 *
 * Please be aware that most of our asynchronous operations are CPU-bound. As a result, when
 * performing `Promise.all` on extensive operations, unexpected results may arise. Exercise
 * caution when leveraging these events for large queries.
 */
var EQueryEvents;
(function (EQueryEvents) {
    /**
     * Will emit on `onQueryPosted` in QueryService:
     * Before creating a query record and requesting available rewards from MP,
     * we process the query and utilize the outcome to inquire about possible rewards.
     */
    EQueryEvents["OnQueryPostedEvaluationProcesses"] = "ProcessesBeforeQueryEvaluation";
    /**
     * Will emit on `returnQueries` in QueryService:
     * Prior to the final processing of the query, we perform certain preliminary tasks.
     * The processed result will subsequently be sent to the MP as the user's response to the query.
     */
    EQueryEvents["ProcessesBeforeReturningQueryEvaluation"] = "ProcessesBeforeQueryEvaluation";
    EQueryEvents["QueryParsing"] = "QueryParsing";
    EQueryEvents["QueryEvaluation"] = "QueryEvaluation";
    EQueryEvents["AgeEvaluation"] = "AgeEvaluation";
    EQueryEvents["GenderEvaluation"] = "GenderEvaluation";
    EQueryEvents["LocationEvaluation"] = "LocationEvaluation";
    EQueryEvents["BrowserActivityEvaluation"] = "BrowserActivityEvaluation";
    EQueryEvents["ChainTransactionEvaluation"] = "ChainTransactionEvaluation";
    EQueryEvents["BalanceEvaluation"] = "BalanceEvaluation";
    EQueryEvents["NftDataEvaluation"] = "NftDataEvaluation";
    EQueryEvents["DiscordEvaluation"] = "DiscordEvaluation";
    EQueryEvents["AgeDataAccess"] = "AgeDataAccess";
    EQueryEvents["GenderDataAccess"] = "GenderDataAccess";
    EQueryEvents["LocationDataAccess"] = "LocationDataAccess";
    EQueryEvents["BrowserActivityDataAccess"] = "BrowserActivityDataAccess";
    EQueryEvents["ChainTransactionDataAccess"] = "ChainTransactionDataAccess";
    EQueryEvents["TransactionDataAccess"] = "TransactionDataAccess";
    EQueryEvents["BalanceDataAccess"] = "BalanceDataAccess";
    EQueryEvents["NftDataAccess"] = "NftDataAccess";
    EQueryEvents["DiscordDataAccess"] = "DiscordDataAccess";
    EQueryEvents["DappEvaluation"] = "DappEvaluation";
    EQueryEvents["Web3AccountDataAccess"] = "Web3AccountDataAccess";
    EQueryEvents["Web3AccountEvaluation"] = "Web3AccountEvaluation";
})(EQueryEvents || (exports.EQueryEvents = EQueryEvents = {}));
//# sourceMappingURL=EQueryEvents.js.map